#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 IfElse
version:              0.85
visibility:           public
id:                   IfElse-0.85-HyI4T2bcRBU4MI8KrRK3hB
key:                  IfElse-0.85-HyI4T2bcRBU4MI8KrRK3hB
license:              BSD-3-Clause
maintainer:           J.R. Heard
author:               J.R. Heard and Wren Thornton
synopsis:             Anaphoric and miscellaneous useful control-flow
description:          Anaphoric and miscellaneous useful control-flow
category:             Control
abi:                  e11755aa6261aad3136a6cbed46b68ab
exposed:              True
exposed-modules:      Control.Monad.IfElse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/IfElse-0.85
library-dirs:         /usr/lib/ghc-9.6.6/site-local/IfElse-0.85
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/IfElse-0.85
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ifelse
hs-libraries:         HSIfElse-0.85-HyI4T2bcRBU4MI8KrRK3hB
depends:              base-4.18.2.1 mtl-2.3.1
haddock-interfaces:   /usr/share/doc/haskell-ifelse/html/IfElse.haddock
haddock-html:         /usr/share/doc/haskell-ifelse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

